import { Card } from "@/components/ui/card"
import { getCurrentUser } from "@/lib/session"
import Image from "next/image"
import { IUser } from "../types"
import { Connect } from "./connect"

export const ProfileSideContent = async ({ user }: { user: IUser }) => {
    const session = await getCurrentUser()
    const arrayOfUserMedia = user.gweets.slice(0, 4)
        .flatMap((gweet) => gweet.media.slice(0, 4).map((media) => ({ id: gweet.id, url: media.url })))
        .slice(0, 4)

    return (
        <div className="space-y-6">
            {arrayOfUserMedia.length > 0 &&
                <Card className="p-6 bg-secondary">
                    <div className={`grid object-cover ${arrayOfUserMedia.length === 1 ? "grid-cols-1"
                        : arrayOfUserMedia.length === 2 ? "grid-cols-2 gap-3"
                            : arrayOfUserMedia.length === 3 || 4 ? "grid-cols-2 grid-rows-2 gap-3"
                                : ""
                        }`}
                    >
                        {arrayOfUserMedia.map(({ id, url }, i) => {
                            const isFirstImage = arrayOfUserMedia.length === 3 && i === 0
                            return (
                                <Card key={id} className={`relative overflow-hidden ${isFirstImage ? "col-span-2 aspect-[2/1]" : "aspect-square"}`}>
                                    <Image src={url} alt="gweet media" fill className="object-cover rounded-lg" />
                                </Card>
                            )
                        })}
                    </div>
                </Card>
            }

            <Card className="p-6 bg-secondary">
                <Connect session={session} />
            </Card>
        </div>
    )
}