"use client"

import { Icons } from '@/components/icons'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import { cn } from '@/lib/utils'
import { zodResolver } from '@hookform/resolvers/zod'
import { usePathname, useRouter, useSearchParams } from 'next/navigation'
import { useState } from 'react'
import { useForm } from 'react-hook-form'
import { z } from 'zod'

interface DocsSearchProps extends React.HTMLAttributes<HTMLFormElement> { }

export default function SearchInput({ className, ...props }: DocsSearchProps) {
    const [searchQuery, setSearchQuery] = useState("")
    const router = useRouter()
    const pathname = usePathname()
    const searchParams = useSearchParams()

    const search = searchParams?.get("query")?.toLowerCase() || ""

    const [query, setQuery] = useState(
        pathname?.split("/")[1] === "search"
            ? decodeURIComponent(search)
            : "",
    )

    function onSearch(event: React.FormEvent) {
        event.preventDefault()

        if (pathname === "/games") {
            if (!searchQuery) {
                router.push(pathname)
                return
            }

            const encoededQuery = encodeURIComponent(searchQuery)
            router.push(`${pathname}?search=${encoededQuery}`)
        } else {
            router.push(`/search?query=${searchQuery}`)
        }
    };

    return (
        <form
            onSubmit={onSearch}
            className={cn("relative w-full flex justify-end items-center", className)}
            {...props}
        >
            <Input
                type="search"
                placeholder="Search..."
                className="rounded-full pr-12"
                value={searchQuery}
                onChange={(event) => setSearchQuery(event.target.value)}
            />
            <Button size="lg" className="absolute align-middle h-8 px-2.5 mr-1">
                <Icons.arrowRight className="h-3 w-3" />
            </Button>
        </form>
    )
}