import { useSearchParams } from "next/navigation"

import { InfiniteGweets } from "@/components/gweets/components/infinite-gweets"
import { useGweets } from "@/components/gweets/hooks/use-gweets"
import LoadingItem from "@/components/loading-item"
import { UserItem } from "@/components/profile/components/user-item"
import { TryAgain } from "@/components/try-again"
import { useSearchPeople } from "../hooks/use-search-people"
import { NoResults } from "./no-results"

export const SearchResults = () => {
    const searchParams = useSearchParams()
    const query = decodeURIComponent(searchParams?.get("query") || "")

    const gweets = useGweets({
        queryKey: ["gweets", "query: ", query],
        type: "search",
        id: query,
    })

    const people = useSearchPeople(query)

    if (gweets.isLoading || gweets.isFetching) return <LoadingItem />

    if (gweets.isError) return <TryAgain />

    return (
        <div className="">
            {gweets?.data?.pages &&
                gweets?.data?.pages[0]?.gweets?.length === 0 &&
                people?.data?.length === 0 ? (
                <NoResults query={query} />
            ) : (
                <div className="">
                    {people?.isSuccess && people?.data?.length > 0 && (
                        <div className="">
                            <h1>People</h1>
                            {people?.data?.map((person) => {
                                return <UserItem key={person?.id} user={person} sessionId={undefined} />
                            })}
                            <button className="">View All</button>
                        </div>
                    )}

                    <div className="">
                        <InfiniteGweets
                            gweets={gweets?.data}
                            hasNextPage={gweets?.hasNextPage}
                            fetchNextPage={gweets?.fetchNextPage}
                            isSuccess={gweets?.isSuccess}
                            isFetchingNextPage={gweets?.isFetchingNextPage}
                        />
                    </div>
                </div>
            )}
        </div>
    )
}